@@ -1,9 +1,10 @@
 # vi:fdm=marker fdl=0
-# $Id: Correlation.pm,v 1.9 2003/12/09 13:34:42 jettero Exp $ 
+# $Id: Correlation.pm,v 1.1 2006/01/25 22:20:42 jettero Exp $ 
 
 package Statistics::Basic::Correlation;
 
 use strict;
+no warnings;
 use Carp;
 use Statistics::Basic::Vector;
 use Statistics::Basic::StdDev;
@@ -143,16 +144,25 @@ __END__
 
 =head1 SYNOPSIS
 
-    A machine to calculate the correlation of given vectors.
+A machine to calculate the correlation of given vectors.
+
+=head1 ENV VARIABLES
+
+=head2 DEBUG
+
+Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
+
+Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
+enable debugging dynamically.
 
 =head1 AUTHOR
 
-    Please contact me with ANY suggestions, no matter how pedantic.
+Please contact me with ANY suggestions, no matter how pedantic.
 
-    Jettero Heller <japh@voltar-confed.org>
+Jettero Heller <japh@voltar-confed.org>
 
 =head1 SEE ALSO
 
-    perl(1)
+perl(1)
 
 =cut
