@@ -1,9 +1,10 @@
 # vi:fdm=marker fdl=0
-# $Id: StdDev.pm,v 1.6 2003/12/02 22:03:59 jettero Exp $ 
+# $Id: StdDev.pm,v 1.1 2006/01/25 22:20:42 jettero Exp $ 
 
 package Statistics::Basic::StdDev;
 
 use strict;
+no warnings;
 use Carp;
 use Statistics::Basic::Variance;
 
@@ -101,16 +102,25 @@ __END__
 
 =head1 SYNOPSIS
 
-    A machine to calculate the standard deviation of a given vector.
+A machine to calculate the standard deviation of a given vector.
+
+=head1 ENV VARIABLES
+
+=head2 DEBUG
+
+Try setting $ENV{DEBUG}=1; or $ENV{DEBUG}=2; to see the internals.
+
+Also, from your bash prompt you can 'DEBUG=1 perl ./myprog.pl' to
+enable debugging dynamically.
 
 =head1 AUTHOR
 
-    Please contact me with ANY suggestions, no matter how pedantic.
+Please contact me with ANY suggestions, no matter how pedantic.
 
-    Jettero Heller <japh@voltar-confed.org>
+Jettero Heller <japh@voltar-confed.org>
 
 =head1 SEE ALSO
 
-    perl(1)
+perl(1)
 
 =cut
